dnl
dnl $Id: cybertec.m4,v 1.11 2002/11/27 11:34:44 cjohns Exp $
dnl
dnl ------------------------------------------------------------------------
dnl
dnl Python Cross-compilation for RTEMS.
dnl
dnl  RTEMS is an open source realtime operating system maintained by
dnl  OAR Corp. See http://www.rtems.com/rtems/rtems.html
dnl
dnl ------------------------------------------------------------------------
dnl
dnl Copyright (c) 2003, Cybertec Pty Ltd.
dnl All rights reserved.
dnl
dnl Chris Johns <cjohns@cybertec.com.au>
dnl 
dnl ------------------------------------------------------------------------
dnl
dnl RTEMS Autoconf and Automake support for embedded development. I am
dnl new to autoconf and automake so suggestions are most welcome.
dnl

dnl
dnl RTEMS_TOP_LEVEL
dnl

AC_DEFUN(RTEMS_TOP_LEVEL,
[
  dnl
  dnl Only support cross-compiling and not Canadian cross.
  dnl
  AS_IF([test $host = $target],
        [AC_MSG_ERROR([invalid \"--target\" configuration option.]
                      [Run configure with a target option:]
                      [    configure --target=<my-target>]
                      [where <my-target> is target you wish to build]
                      [Python for.])],
        )
  AS_IF([test $host != $build],
        [AC_MSG_ERROR([Canadian cross is not supported.]
         [Check your \"--host\" and \"--build\" options.])],
        )

  dnl
  dnl Must build in a separate tree to the source.
  dnl
  AC_MSG_CHECKING([that a separate build tree is being used])
  ac_tmp_cwd=`/bin/pwd`
  AS_IF([test "${srcdir} = "."], 
        [srcdir=${ac_tmp_cwd}],
        )
  AS_IF([test "${ac_tmp_cwd} = "${srcdir}"],
        [AC_MSG_RESULT([no])
         AC_MSG_ERROR([This configure script should not be run inside the source tree.]
                      [Instead please use a separate build tree])],
        [AC_MSG_RESULT([yes])])
  export topdir=$srcdir
])

dnl
dnl RTEMS_SRC_TOP(TOPDIR, SRCDIR, TOP)
dnl

AC_DEFUN(RTEMS_SRC_TOP,
[
  dnl
  dnl Isolate the leading ../ that are added to nested configure.in's.
  dnl
  $3=`echo $2 | sed -e "s%$topdir.*%%"`$1
])

dnl 
dnl RTEMS_CHECK_TOOL(VARIABLE, PROG-TO-CHECK-FOR [,VALUE-IF-NOT-FOUND [, PATH]])
dnl
AC_DEFUN(RTEMS_CHECK_TOOL,
[
  dnl
  dnl The setting of cross_compiling is here as I cannot seem to figure why it 
  dnl is not set by autoconf. I have found the host_alias and build_alias field
  dnl are not set. As a result cross_compiling is also not set.
  dnl
  AS_IF([test "x$target != "x$host],
        [ac_tmp_tool_prefix=${target_alias}-
         cross_compiling=yes])
  AC_CHECK_PROG($1, ${ac_tmp_tool_prefix}$2, ${ac_tmp_tool_prefix}$2, $3, $4)
])

dnl
dnl RTEMS_CANONICALIZE_TOOLS
dnl
AC_DEFUN(RTEMS_CANONICALIZE_TOOLS,
[
  AC_REQUIRE([RTEMS_PROG_CC])

  dnl
  dnl FIXME: What shall be done if these tools are not available?
  dnl
  RTEMS_CHECK_TOOL(AR, ar, no)
  RTEMS_CHECK_TOOL(AS, as, no)
  RTEMS_CHECK_TOOL(LD, ld, no)
  RTEMS_CHECK_TOOL(NM, nm, no)

  dnl
  dnl special treatment of ranlib
  dnl
  RTEMS_CHECK_TOOL(RANLIB, ranlib, :)

  dnl
  dnl NOTE: These may not be available if not using gnutools
  dnl
  RTEMS_CHECK_TOOL(OBJCOPY, objcopy, no)
  RTEMS_CHECK_TOOL(SIZE, size, no)
  RTEMS_CHECK_TOOL(STRIP, strip, :)
])

dnl
dnl RTEMS_PROG_CC
dnl
AC_DEFUN(RTEMS_PROG_CC,
[
  AC_BEFORE([$0], [AC_PROG_AS])
  AC_BEFORE([$0], [AC_PROG_CPP])
  AC_BEFORE([$0], [AC_PROG_CXX])
  AC_BEFORE([$0], [AC_PROG_CC])
  AC_BEFORE([$0], [RTEMS_CANONICALIZE_TOOLS])

  RTEMS_CHECK_TOOL(CC, gcc)
  test -z "$CC" && AC_MSG_ERROR([no acceptable cc found in \$PATH])

  RTEMS_CHECK_TOOL(CXX, g++)
  test -z "$CXX" && AC_MSG_ERROR([no acceptable CXX found in \$PATH])

  RTEMS_CHECK_TOOL(LD, ld)
  test -z "$LD" && AC_MSG_ERROR([no acceptable LD found in \$PATH])

  AC_SUBST(LD, $LD)

  AC_PROG_CC
  AC_PROG_CXX
  AC_PROG_CPP
  AM_PROG_AS
])

dnl
dnl RTEMS_PROG_CC_FOR_TARGET
dnl

AC_DEFUN(RTEMS_PROG_CC_FOR_TARGET,
[
  dnl
  dnl Check target cc.
  dnl
  RTEMS_PROG_CC
])

dnl
dnl RTEMS_ENABLE_RTEMS(BSP)
dnl
dnl Note, ${prefix} should be set to /opt/rtems by default. This
dnl is currently not set.
dnl
AC_DEFUN(RTEMS_ENABLE_RTEMS,
[
  AC_MSG_CHECKING([for rtems])
  AC_ARG_ENABLE(rtems,
                AC_HELP_STRING([--enable-rtems],
                               [specify the path to RTEMS]),
                [rtems=${enableval}],
                [rtems=${prefix}])

  dnl
  dnl Just check is a file is present. First look for a
  dnl 4.5.0 type structure.
  dnl
  AS_IF([test -f ${rtems}/$1/lib/librtemsall.a],
        [ac_tmp_found=yes
         rtems_inc_path=${rtems}/$1/lib/include
         rtems_lib_path=${rtems}/$1/lib
         rtems_lib=-lrtemsall],
        [AS_IF([test -f ${rtems}/${target_alias}/lib/$1/librtemscpu.a],
               [ac_tmp_found=yes
                rtems=${rtems}/${target_alias}
                rtems_inc_path=${rtems}/lib/include
                rtems_lib_path=${rtems}/lib/$1
                rtems_lib="-lrtemscpu"],
               [ac_tmp_found=no])])

  AS_IF([test ! x$ac_tmp_found = xyes], 
        [AC_MSG_RESULT(no)
         AC_MSG_ERROR([RTEMS not found])])

  AM_CONDITIONAL(RTEMS, test true)
  AC_SUBST(RTEMS, ${rtems})
  AC_SUBST(RTEMS_INC_PATH, $rtems_inc_path)
  AC_SUBST(RTEMS_LIB_PATH, $rtems_lib_path)
  AC_SUBST(RTEMS_LIB, $rtems_lib)

  AC_MSG_RESULT([$rtems_path])
])

